import sys

import pyglet
from pyglet.window import key

from cocos.director import director
from cocos.layer import *
from cocos.scene import Scene
from cocos.menu import *

from levels import Intro
from instructions import Instructions
from layers import StatusLayer
from misc import BACKGROUND


class MainMenu(Menu):
    def __init__(self):
        super(MainMenu, self).__init__('Johnny saves the world!')

        self.font_title = 'StraightJacket BB'
        self.font_title_size = 40
        self.font_title_color = (255, 255, 255, 255)
        self.font_items = 'StraightJacket BB'
        self.font_items_size = 24
        self.font_items_selected_size = 32

        self.menu_valign = CENTER
        self.menu_halign = CENTER

        self.add_item(MenuItem('New Game', self.on_new_game))
        self.add_item(MenuItem('Instructions', self.on_instructions))
        self.add_item(MenuItem('Options', self.on_options))
        self.add_item(MenuItem('Quit', self.on_quit))
        self.build_items()

        self.copyright = pyglet.text.Label(
                "A game by Rob De Almeida for Pyweek #6",
                font_name='',
                font_size=10,
                x=15,
                y=15,
                batch=self.batch,
        )

    def on_key_release(self, key_pressed, mod):
        if key_pressed == key.Q:
            self.on_quit()
        elif key_pressed == key.O:
            self.on_options()
        elif key_pressed == key.N:
            self.on_new_game()
        elif key_pressed == key.I:
            self.on_instructions()

    def on_new_game(self):
        director.push(Scene(BACKGROUND, Intro()))

    def on_instructions(self):
        director.push(Scene(BACKGROUND, Instructions(), StatusLayer()))

    def on_options(self):
        director.push(Scene(BACKGROUND, OptionsMenu()))

    def on_quit(self):
        sys.exit()


class OptionsMenu(Menu):
    def __init__(self):
        super(OptionsMenu, self).__init__('Options')

        self.font_title = 'StraightJacket BB'
        self.font_title_size = 40
        self.font_title_color = (255, 255, 255, 255)
        self.font_items = 'StraightJacket BB'
        self.font_items_size = 24
        self.font_items_selected_size = 32

        self.menu_valign = CENTER
        self.menu_halign = CENTER

        self.add_item(MenuItem('Fullscreen', self.on_fullscreen))
        self.add_item(ToggleMenuItem('Show FPS', False, self.on_show_fps))
        self.add_item(MenuItem('OK', self.on_quit))
        self.build_items()

        self.fullscreen = False

    def on_key_release(self, key_pressed, mod):
        if key_pressed == key.O:
            self.on_quit()
        elif key_pressed == key.S:
            self.on_show_fps(not director.show_FPS)
            self.items[1].on_key_press(key.ENTER, mod)
        elif key_pressed == key.F:
            self.on_fullscreen()

    def on_fullscreen(self):
        self.fullscreen = not self.fullscreen
        director.window.set_fullscreen(self.fullscreen)

    def on_show_fps(self, value):
        director.show_FPS = value

    def on_quit(self):
        director.scene.end('Back to main menu')
